Struct amazon_sp_orders::models::buyer_customized_info_detail::BuyerCustomizedInfoDetail
source · [−]Expand description
BuyerCustomizedInfoDetail : Buyer information for custom orders from the Amazon Custom program.
Fields
customized_url: Option<String>The location of a zip file containing Amazon Custom data.
Implementations
sourceimpl BuyerCustomizedInfoDetail
impl BuyerCustomizedInfoDetail
sourcepub fn new() -> BuyerCustomizedInfoDetail
pub fn new() -> BuyerCustomizedInfoDetail
Buyer information for custom orders from the Amazon Custom program.